==> napari-simpleitk-image-processing-0.2.1.tar.gz: napari-simpleitk-image-processing-0.2.1/src/napari_simpleitk_image_processing/_function.py <==
from napari_plugin_engine import napari_hook_implementation

@napari_hook_implementation
def napari_experimental_provide_function():
    from ._simpleitk_image_processing import median_filter, gaussian_blur, threshold_otsu, threshold_intermodes, \
        threshold_kittler_illingworth, threshold_li, threshold_moments, threshold_renyi_entropy, \
        threshold_shanbhag, threshold_yen, threshold_isodata, threshold_triangle, threshold_huang, \
        threshold_maximum_entropy, \
        signed_maurer_distance_map, morphological_watershed, morphological_gradient, standard_deviation_filter, \
        simple_linear_iterative_clustering, scalar_image_k_means_clustering,\
        connected_component_labeling, \
        touching_objects_labeling, watershed_otsu_labeling, binary_fill_holes, invert_intensity, \
        bilateral_filter, laplacian_filter, laplacian_of_gaussian_filter, binominal_blur_filter, \
        canny_edge_detection, gradient_magnitude, h_maxima, \
        h_minima, otsu_multiple_thresholds, regional_maxima, regional_minima, \
        richardson_lucy_deconvolution, wiener_deconvolution, tikhonov_deconvolution, rescale_intensity, \
        sobel, black_top_hat, white_top_hat, adaptive_histogram_equalization, curvature_flow_denoise, \
        relabel_component, label_contour, \
        label_statistics

    return [median_filter,
            gaussian_blur,
            threshold_otsu,
            threshold_intermodes,
            threshold_kittler_illingworth,
            threshold_li,
            threshold_moments,
            threshold_renyi_entropy,
            threshold_shanbhag,
            threshold_yen,
            threshold_isodata,
            threshold_triangle,
            threshold_huang,
            threshold_maximum_entropy,
            signed_maurer_distance_map,
            morphological_watershed,
            morphological_gradient,
            standard_deviation_filter,
            simple_linear_iterative_clustering,
            scalar_image_k_means_clustering,
            connected_component_labeling,
            touching_objects_labeling,
            watershed_otsu_labeling,
            binary_fill_holes,
            invert_intensity,
            bilateral_filter,
            laplacian_filter,
            laplacian_of_gaussian_filter,
            binominal_blur_filter,
            canny_edge_detection,
            gradient_magnitude,
            h_maxima,
            h_minima,
            otsu_multiple_thresholds,
            regional_maxima,
            regional_minima,
            richardson_lucy_deconvolution,
            wiener_deconvolution,
            tikhonov_deconvolution,
            rescale_intensity,
            sobel,
            black_top_hat,
            white_top_hat,
            adaptive_histogram_equalization,
            curvature_flow_denoise,
            relabel_component,
            label_contour,
            label_statistics
            ]

==> napari-simpleitk-image-processing-0.2.3.tar.gz: napari-simpleitk-image-processing-0.2.3/src/napari_simpleitk_image_processing/_function.py <==
from napari_plugin_engine import napari_hook_implementation

@napari_hook_implementation
def napari_experimental_provide_function():
    from ._simpleitk_image_processing import median_filter, gaussian_blur, threshold_otsu, threshold_intermodes, \
        threshold_kittler_illingworth, threshold_li, threshold_moments, threshold_renyi_entropy, \
        threshold_shanbhag, threshold_yen, threshold_isodata, threshold_triangle, threshold_huang, \
        threshold_maximum_entropy, \
        signed_maurer_distance_map, morphological_watershed, morphological_gradient, standard_deviation_filter, \
        simple_linear_iterative_clustering, scalar_image_k_means_clustering,\
        connected_component_labeling, \
        touching_objects_labeling, watershed_otsu_labeling, binary_fill_holes, invert_intensity, \
        bilateral_filter, laplacian_filter, laplacian_of_gaussian_filter, binominal_blur_filter, \
        canny_edge_detection, gradient_magnitude, h_maxima, \
        h_minima, otsu_multiple_thresholds, regional_maxima, regional_minima, \
        richardson_lucy_deconvolution, wiener_deconvolution, tikhonov_deconvolution, rescale_intensity, \
        sobel, black_top_hat, white_top_hat, adaptive_histogram_equalization, curvature_flow_denoise, \
        relabel_component, label_contour, \
        label_statistics, pixel_count_map, elongation_map, feret_diameter_map, roundness_map

    return [median_filter,
            gaussian_blur,
            threshold_otsu,
            threshold_intermodes,
            threshold_kittler_illingworth,
            threshold_li,
            threshold_moments,
            threshold_renyi_entropy,
            threshold_shanbhag,
            threshold_yen,
            threshold_isodata,
            threshold_triangle,
            threshold_huang,
            threshold_maximum_entropy,
            signed_maurer_distance_map,
            morphological_watershed,
            morphological_gradient,
            standard_deviation_filter,
            simple_linear_iterative_clustering,
            scalar_image_k_means_clustering,
            connected_component_labeling,
            touching_objects_labeling,
            watershed_otsu_labeling,
            binary_fill_holes,
            invert_intensity,
            bilateral_filter,
            laplacian_filter,
            laplacian_of_gaussian_filter,
            binominal_blur_filter,
            canny_edge_detection,
            gradient_magnitude,
            h_maxima,
            h_minima,
            otsu_multiple_thresholds,
            regional_maxima,
            regional_minima,
            richardson_lucy_deconvolution,
            wiener_deconvolution,
            tikhonov_deconvolution,
            rescale_intensity,
            sobel,
            black_top_hat,
            white_top_hat,
            adaptive_histogram_equalization,
            curvature_flow_denoise,
            relabel_component,
            label_contour,
            label_statistics,
            pixel_count_map,
            elongation_map,
            feret_diameter_map,
            roundness_map
            ]
